@@ -5,11 +5,12 @@ our $VERSION = '1.1.0';
 use Moose;
 use 5.14.2;
 
-use Encode;
-use DBI qw(:utils);
-use JSON::PP;
-use Digest::MD5 qw(md5_hex);
 use Data::Dumper;
+use DBI qw(:utils);
+use Digest::MD5 qw(md5_hex);
+use Encode;
+use JSON::PP;
+use Log::Any qw($log);
 
 use Zonemaster::Backend::Config;
 
@@ -34,11 +35,22 @@ sub dbh {
         return $dbh;
     }
     else {
-        my $connection_string   = $self->config->DB_connection_string( 'mysql' );
-        my $connection_args     = { RaiseError => 1, AutoCommit => 1 };
-        my $connection_user     = $self->config->DB_user();
-        my $connection_password = $self->config->DB_password();
-        $dbh = DBI->connect( $connection_string, $connection_user, $connection_password, $connection_args );
+        my $database = $self->config->MYSQL_database;
+        my $host     = $self->config->MYSQL_host;
+        my $user     = $self->config->MYSQL_user();
+        my $password = $self->config->MYSQL_password();
+
+        $log->notice( "Connecting to MySQL: database=$database host=$host user=$user" ) if $log->is_notice;
+        $dbh = DBI->connect(
+            "DBI:mysql:database=$database;host=$host",
+            $user,
+            $password,
+            {
+                RaiseError => 1,
+                AutoCommit => 1
+            }
+        );
+
         $dbh->{AutoInactiveDestroy} = 1;
         $self->dbhandle( $dbh );
         return $dbh;
@@ -102,7 +114,7 @@ sub create_new_batch_job {
 }
 
 sub create_new_test {
-    my ( $self, $domain, $test_params, $minutes_between_tests_with_same_params, $batch_id ) = @_;
+    my ( $self, $domain, $test_params, $seconds_between_tests_with_same_params, $batch_id ) = @_;
 
     my $dbh = $self->dbh;
 
@@ -117,27 +129,22 @@ sub create_new_test {
 
     eval {
         $dbh->do( q[LOCK TABLES test_results WRITE] );
-        my ( $recent_id, $recent_hash_id ) = $dbh->selectrow_array(
+        my ( $recent_hash_id ) = $dbh->selectrow_array(
             q[
-SELECT id, hash_id FROM test_results WHERE params_deterministic_hash = ? AND (TO_SECONDS(NOW()) - TO_SECONDS(creation_time)) < ?
-],
-            undef, $test_params_deterministic_hash, 60 * $minutes_between_tests_with_same_params,
+            SELECT hash_id FROM test_results WHERE params_deterministic_hash = ? AND (TO_SECONDS(NOW()) - TO_SECONDS(creation_time)) < ?
+            ],
+            undef, $test_params_deterministic_hash, $seconds_between_tests_with_same_params,
         );
 
-        if ( $recent_id ) {
+        if ( $recent_hash_id ) {
             # A recent entry exists, so return its id
-            if ( $recent_id > $self->config->force_hash_id_use_in_API_starting_from_id() ) {
-                $result_id = $recent_hash_id;
-            }
-            else {
-                $result_id = $recent_id;
-            }
+            $result_id = $recent_hash_id;
         }
         else {
             $dbh->do(
                 q[
-            INSERT INTO test_results (batch_id, priority, queue, params_deterministic_hash, params, domain, test_start_time, undelegated) VALUES (?, ?,?,?,?,?, NOW(),?)
-        ],
+                INSERT INTO test_results (batch_id, priority, queue, params_deterministic_hash, params, domain, test_start_time, undelegated) VALUES (?, ?,?,?,?,?, NOW(),?)
+                ],
                 undef,
                 $batch_id,
                 $priority,
@@ -148,15 +155,10 @@ SELECT id, hash_id FROM test_results WHERE params_deterministic_hash = ? AND (TO
                 ($test_params->{nameservers})?(1):(0),
             );
             
-            my ( $id, $hash_id ) = $dbh->selectrow_array(
-                "SELECT id, hash_id FROM test_results WHERE params_deterministic_hash='$test_params_deterministic_hash' ORDER BY id DESC LIMIT 1" );
+            my ( undef, $hash_id ) = $dbh->selectrow_array(
+                "SELECT id, hash_id FROM test_results WHERE params_deterministic_hash=? ORDER BY id DESC LIMIT 1", undef, $test_params_deterministic_hash);
                 
-            if ( $id > $self->config->force_hash_id_use_in_API_starting_from_id() ) {
-                $result_id = $hash_id;
-            }
-            else {
-                $result_id = $id;
-            }
+            $result_id = $hash_id;
         }
     };
     $dbh->do( q[UNLOCK TABLES] );
@@ -167,19 +169,17 @@ SELECT id, hash_id FROM test_results WHERE params_deterministic_hash = ? AND (TO
 sub test_progress {
     my ( $self, $test_id, $progress ) = @_;
 
-    my $id_field = $self->_get_allowed_id_field_name($test_id);
-
     my $dbh = $self->dbh;
     if ( $progress ) {
         if ($progress == 1) {
-            $dbh->do( "UPDATE test_results SET progress=?, test_start_time=NOW() WHERE $id_field=? AND progress <> 100", undef, $progress, $test_id );
+            $dbh->do( "UPDATE test_results SET progress=?, test_start_time=NOW() WHERE hash_id=? AND progress <> 100", undef, $progress, $test_id );
         }
         else {
-            $dbh->do( "UPDATE test_results SET progress=? WHERE $id_field=? AND progress <> 100", undef, $progress, $test_id );
+            $dbh->do( "UPDATE test_results SET progress=? WHERE hash_id=? AND progress <> 100", undef, $progress, $test_id );
         }
     }
 
-    my ( $result ) = $self->dbh->selectrow_array( "SELECT progress FROM test_results WHERE $id_field=?", undef, $test_id );
+    my ( $result ) = $self->dbh->selectrow_array( "SELECT progress FROM test_results WHERE hash_id=?", undef, $test_id );
 
     return $result;
 }
@@ -187,8 +187,7 @@ sub test_progress {
 sub get_test_params {
     my ( $self, $test_id ) = @_;
 
-    my $id_field = $self->_get_allowed_id_field_name($test_id);
-    my ( $params_json ) = $self->dbh->selectrow_array( "SELECT params FROM test_results WHERE $id_field=?", undef, $test_id );
+    my ( $params_json ) = $self->dbh->selectrow_array( "SELECT params FROM test_results WHERE hash_id=?", undef, $test_id );
 
     my $result;
     eval {
@@ -203,15 +202,13 @@ sub get_test_params {
 sub test_results {
     my ( $self, $test_id, $new_results ) = @_;
 
-    my $id_field = $self->_get_allowed_id_field_name($test_id);
-    
     if ( $new_results ) {
-        $self->dbh->do( qq[UPDATE test_results SET progress=100, test_end_time=NOW(), results = ? WHERE $id_field=? AND progress < 100],
+        $self->dbh->do( qq[UPDATE test_results SET progress=100, test_end_time=NOW(), results = ? WHERE hash_id=? AND progress < 100],
             undef, $new_results, $test_id );
     }
 
     my $result;
-    my ( $hrefs ) = $self->dbh->selectall_hashref( "SELECT id, hash_id, CONVERT_TZ(`creation_time`, \@\@session.time_zone, '+00:00') AS creation_time, params, results FROM test_results WHERE $id_field=?", $id_field, undef, $test_id );
+    my ( $hrefs ) = $self->dbh->selectall_hashref( "SELECT id, hash_id, CONVERT_TZ(`creation_time`, \@\@session.time_zone, '+00:00') AS creation_time, params, results FROM test_results WHERE hash_id=?", 'hash_id', undef, $test_id );
     $result            = $hrefs->{$test_id};
     $result->{params}  = decode_json( $result->{params} );
     $result->{results} = decode_json( $result->{results} );
@@ -225,8 +222,6 @@ sub get_test_history {
     my @results;
     my $sth = {};
 
-    my $use_hash_id_from_id = $self->config->force_hash_id_use_in_API_starting_from_id();
-
     my $undelegated = "";
     if ($p->{filter} eq "undelegated") {
         $undelegated = 1;
@@ -285,7 +280,7 @@ sub get_test_history {
         push(
             @results,
             {
-                id               => ($h->{id} > $use_hash_id_from_id)?($h->{hash_id}):($h->{id}),
+                id               => $h->{hash_id},
                 creation_time    => $h->{creation_time},
                 overall_result   => $overall,
             }
@@ -341,27 +336,38 @@ sub add_batch_job {
     return $batch_id;
 }
 
-sub build_process_unfinished_tests_select_query {
+sub select_unfinished_tests {
     my ( $self ) = @_;
-    
-    if ($self->config->lock_on_queue()) {
-        return "
+
+    if ( $self->config->ZONEMASTER_lock_on_queue ) {
+        my $sth = $self->dbh->prepare( "
             SELECT hash_id, results, nb_retries
-            FROM test_results 
-            WHERE test_start_time < DATE_SUB(NOW(), INTERVAL ".$self->config->MaxZonemasterExecutionTime()." SECOND) 
-            AND nb_retries <= ".$self->config->maximal_number_of_retries()." 
+            FROM test_results
+            WHERE test_start_time < DATE_SUB(NOW(), INTERVAL ? SECOND)
+            AND nb_retries <= ?
             AND progress > 0
             AND progress < 100
-            AND queue = ".$self->config->lock_on_queue();
+            AND queue = ?" );
+        $sth->execute(    #
+            $self->config->ZONEMASTER_max_zonemaster_execution_time,
+            $self->config->ZONEMASTER_maximal_number_of_retries,
+            $self->config->ZONEMASTER_lock_on_queue,
+        );
+        return $sth;
     }
     else {
-        return "
+        my $sth = $self->dbh->prepare( "
             SELECT hash_id, results, nb_retries
-            FROM test_results 
-            WHERE test_start_time < DATE_SUB(NOW(), INTERVAL ".$self->config->MaxZonemasterExecutionTime()." SECOND) 
-            AND nb_retries <= ".$self->config->maximal_number_of_retries()." 
+            FROM test_results
+            WHERE test_start_time < DATE_SUB(NOW(), INTERVAL ? SECOND)
+            AND nb_retries <= ?
             AND progress > 0
-            AND progress < 100";
+            AND progress < 100" );
+        $sth->execute(    #
+            $self->config->ZONEMASTER_max_zonemaster_execution_time,
+            $self->config->ZONEMASTER_maximal_number_of_retries,
+        );
+        return $sth;
     }
 }
 
