@@ -40,33 +40,38 @@ sub new {
     my $self = {};
     bless( $self, $type );
 
-    my $config = Zonemaster::Backend::Config->load_config();
+    if ( ! $params || ! $params->{config} ) {
+        handle_exception('new', "Missing 'config' parameter", '001');
+    }
 
-    if ( $params && $params->{db} ) {
-        eval {
-            eval "require $params->{db}";
-            die "$@ \n" if $@;
-            $self->{db} = "$params->{db}"->new( { config => $config } );
-        };
-        if ($@) {
-            handle_exception('new', "Failed to initialize the [$params->{db}] database backend module: [$@]", '001');
-        }
-    }
-    else {
-        eval {
-            my $backend_module = "Zonemaster::Backend::DB::" . $config->BackendDBType();
-            eval "require $backend_module";
-            die "$@ \n" if $@;
-            $self->{db} = $backend_module->new( { config => $config } );
-        };
-        if ($@) {
-            handle_exception('new', "Failed to initialize the [$params->{db}] database backend module: [$@]", '002');
-        }
+    $self->{config} = $params->{config};
+
+    my $dbtype;
+    if ( $params->{dbtype} ) {
+        $dbtype = $self->{config}->check_db($params->{dbtype});
+    } else {
+        $dbtype = $self->{config}->DB_engine;
     }
 
+    $self->_init_db($dbtype);
+
     return ( $self );
 }
 
+sub _init_db {
+    my ( $self, $dbtype ) = @_;
+
+    eval {
+        my $backend_module = "Zonemaster::Backend::DB::" . $dbtype;
+        eval "require $backend_module";
+        die "$@ \n" if $@;
+        $self->{db} = $backend_module->new( { config => $self->{config} } );
+    };
+    if ($@) {
+        handle_exception('_init_db', "Failed to initialize the [$dbtype] database backend module: [$@]", '002');
+    }
+}
+
 sub handle_exception {
     my ( $method, $exception, $exception_id ) = @_;
 
@@ -89,23 +94,23 @@ sub version_info {
     if ($@) {
         handle_exception('version_info', $@, '003');
     }
-    
+
     return \%ver;
 }
 
 $json_schemas{profile_names} = joi->object->strict;
 sub profile_names {
-    my ($self) = @_;
+    my ( $self ) = @_;
 
     my @profiles;
     eval {
-        @profiles = Zonemaster::Backend::Config->load_config()->ListPublicProfiles();
+        @profiles = $self->{config}->ListPublicProfiles();
 
     };
     if ($@) {
         handle_exception('profile_names', $@, '004');
     }
-    
+
     return \@profiles;
 }
 
@@ -113,9 +118,9 @@ sub profile_names {
 # derived from the locale tags set in the configuration file.
 $json_schemas{get_language_tags} = joi->object->strict;
 sub get_language_tags {
-    my ($self) = @_;
+    my ( $self ) = @_;
 
-    my @lang = Zonemaster::Backend::Config->load_config()->ListLanguageTags();
+    my @lang = $self->{config}->ListLanguageTags();
 
     return \@lang;
 }
@@ -126,8 +131,9 @@ $json_schemas{get_host_by_name} = joi->object->strict->props(
 sub get_host_by_name {
     my ( $self, $params ) = @_;
     my @adresses;
+
     eval {
-        my $ns_name  = $params->{"hostname"};
+        my $ns_name  = $params->{hostname};
 
         @adresses = map { {$ns_name => $_->short} } $recursor->get_addresses_for($ns_name);
         @adresses = { $ns_name => '0.0.0.0' } if not @adresses;
@@ -136,7 +142,7 @@ sub get_host_by_name {
     if ($@) {
         handle_exception('get_host_by_name', $@, '005');
     }
-    
+
     return \@adresses;
 }
 
@@ -145,15 +151,11 @@ $json_schemas{get_data_from_parent_zone} = joi->object->strict->props(
 );
 sub get_data_from_parent_zone {
     my ( $self, $params ) = @_;
-    my $domain = "";
 
     my $result = eval {
-		my %result;
-        if (ref \$params eq "SCALAR") {
-            $domain = $params;
-        } else {
-            $domain = $params->{"domain"};
-        }
+        my %result;
+
+        my $domain = $params->{domain};
 
         my ( $dn, $dn_syntax ) = $self->_check_domain( $domain, 'Domain name' );
         return $dn_syntax if ( $dn_syntax->{status} eq 'nok' );
@@ -179,77 +181,67 @@ sub get_data_from_parent_zone {
 
         $result{ns_list} = \@ns_list;
         $result{ds_list} = \@ds_list;
-		return \%result;
+        return \%result;
     };
     if ($@) {
         handle_exception('get_data_from_parent_zone', $@, '006');
     }
     elsif ($result) {
-		return $result;
+        return $result;
     }
 }
 
 
 sub _check_domain {
-    my ( $self, $dn, $type ) = @_;
+    my ( $self, $domain, $type ) = @_;
 
-    my $result = eval {
-        if ( !defined( $dn ) ) {
-            return ( $dn, { status => 'nok', message => encode_entities( "$type required" ) } );
-        }
+    if ( !defined( $domain ) ) {
+        return ( $domain, { status => 'nok', message => encode_entities( "$type required" ) } );
+    }
 
-        if ( $dn =~ m/[^[:ascii:]]+/ ) {
-            if ( Zonemaster::LDNS::has_idn() ) {
-                eval { $dn = Zonemaster::LDNS::to_idn( $dn ); };
-                if ( $@ ) {
-                    return (
-                        $dn,
-                        {
-                            status  => 'nok',
-                            message => encode_entities( "The domain name is not a valid IDNA string and cannot be converted to an A-label" )
-                        }
-                    );
-                }
-            }
-            else {
+    if ( $domain =~ m/[^[:ascii:]]+/ ) {
+        if ( Zonemaster::LDNS::has_idn() ) {
+            eval { $domain = Zonemaster::LDNS::to_idn( $domain ); };
+            if ( $@ ) {
                 return (
-                    $dn,
+                    $domain,
                     {
-                        status => 'nok',
-                        message =>
-                        encode_entities( "$type contains non-ascii characters and IDNA is not installed" )
+                        status  => 'nok',
+                        message => encode_entities( "The domain name is not a valid IDNA string and cannot be converted to an A-label" )
                     }
                 );
             }
         }
-
-        if( $dn !~ m/^[\-a-zA-Z0-9\.\_]+$/ ) {
+        else {
             return (
-                $dn,
+                $domain,
                 {
-                status  => 'nok',
-                message => encode_entities( "The domain name character(s) not supported")
+                    status  => 'nok',
+                    message => encode_entities( "$type contains non-ascii characters and IDNA is not installed" )
                 }
             );
         }
+    }
 
-    };
-    if ($@) {
-        handle_exception('_check_domain', $@, '007');
+    if ( $domain !~ m/^[\-a-zA-Z0-9\.\_]+$/ ) {
+        return (
+            $domain,
+            {
+                status  => 'nok',
+                message => encode_entities( "The domain name character(s) not supported" )
+            }
+        );
     }
-    elsif ($result) {
-		return $result;
-    }
-    
+
     my %levels = Zonemaster::Engine::Logger::Entry::levels();
     my @res;
-    @res = Zonemaster::Engine::Test::Basic->basic00($dn);
+    @res = Zonemaster::Engine::Test::Basic->basic00( $domain );
     @res = grep { $_->numeric_level >= $levels{ERROR} } @res;
-    if (@res != 0) {
-        return ( $dn, { status => 'nok', message => encode_entities( "$type name or label is too long" ) } );
+    if ( @res != 0 ) {
+        return ( $domain, { status => 'nok', message => encode_entities( "$type name or label is too long" ) } );
     }
 
-    return ( $dn, { status => 'ok', message => 'Syntax ok' } );
+    return ( $domain, { status => 'ok', message => 'Syntax ok' } );
 }
 
 sub validate_syntax {
@@ -299,12 +291,12 @@ sub validate_syntax {
         }
 
         if ( defined $syntax_input->{profile} ) {
-            my @profiles = map lc, Zonemaster::Backend::Config->load_config()->ListPublicProfiles();
+            my @profiles = map lc, $self->{config}->ListPublicProfiles();
             return { status => 'nok', message => encode_entities( "Invalid profile option format" ) }
             unless ( grep { $_ eq lc $syntax_input->{profile} } @profiles );
         }
 
-        my ( $dn, $dn_syntax ) = $self->_check_domain( $syntax_input->{domain}, 'Domain name' );
+        my ( undef, $dn_syntax ) = $self->_check_domain( $syntax_input->{domain}, 'Domain name' );
 
         return $dn_syntax if ( $dn_syntax->{status} eq 'nok' );
 
@@ -388,14 +380,13 @@ sub start_domain_test {
 
         if ($params->{config}) {
             $params->{config} =~ s/[^\w_]//isg;
-            die "Unknown test configuration: [$params->{config}]\n" unless ( Zonemaster::Backend::Config->load_config()->GetCustomConfigParameter('ZONEMASTER', $params->{config}) );
+            die "Unknown test configuration: [$params->{config}]\n" unless ( $self->{config}->GetCustomConfigParameter('ZONEMASTER', $params->{config}) );
         }
 
         $params->{priority}  //= 10;
         $params->{queue}     //= 0;
-        my $minutes_between_tests_with_same_params = 10;
 
-        $result = $self->{db}->create_new_test( $params->{domain}, $params, $minutes_between_tests_with_same_params );
+        $result = $self->{db}->create_new_test( $params->{domain}, $params, $self->{config}->ZONEMASTER_age_reuse_previous_test );
     };
     if ($@) {
         handle_exception('start_domain_test', $@, '009');
@@ -409,17 +400,10 @@ $json_schemas{test_progress} = joi->object->strict->props(
 );
 sub test_progress {
     my ( $self, $params ) = @_;
-    
+
     my $result = 0;
     eval {
-        my $test_id = "";
-        if (ref \$params eq "SCALAR") {
-            $test_id = $params;
-        } else {
-            $test_id = $params->{"test_id"};
-        }
-
-
+        my $test_id = $params->{test_id};
         $result = $self->{db}->test_progress( $test_id );
     };
     if ($@) {
@@ -434,7 +418,8 @@ $json_schemas{get_test_params} = joi->object->strict->props(
 );
 sub get_test_params {
     my ( $self, $params ) = @_;
-    my $test_id = $params->{"test_id"};
+
+    my $test_id = $params->{test_id};
 
     my $result = 0;
 
@@ -459,7 +444,7 @@ sub get_test_results {
     my $translator;
     $translator = Zonemaster::Backend::Translator->new;
 
-    my %locale = Zonemaster::Backend::Config->load_config()->Language_Locale_hash();
+    my %locale = $self->{config}->Language_Locale_hash();
     if ( $locale{$params->{language}} ) {
         if ( $locale{$params->{language}} eq 'NOT-UNIQUE') {
             die "Language string not unique: '$params->{language}'\n";
@@ -548,16 +533,16 @@ $json_schemas{get_test_history} = joi->object->strict->props(
     )->required
 );
 sub get_test_history {
-    my ( $self, $p ) = @_;
+    my ( $self, $params ) = @_;
 
     my $results;
 
     eval {
-        $p->{offset} //= 0;
-        $p->{limit} //= 200;
-        $p->{filter} //= "all";
+        $params->{offset} //= 0;
+        $params->{limit} //= 200;
+        $params->{filter} //= "all";
 
-        $results = $self->{db}->get_test_history( $p );
+        $results = $self->{db}->get_test_history( $params );
     };
     if ($@) {
         handle_exception('get_test_history', $@, '013');
@@ -571,7 +556,7 @@ $json_schemas{add_api_user} = joi->object->strict->props(
     api_key => $zm_validator->api_key->required,
 );
 sub add_api_user {
-    my ( $self, $p, undef, $remote_ip ) = @_;
+    my ( $self, $params, undef, $remote_ip ) = @_;
 
     my $result = 0;
 
@@ -585,7 +570,7 @@ sub add_api_user {
         }
 
         if ( $allow ) {
-            $result = 1 if ( $self->{db}->add_api_user( $p->{username}, $p->{api_key} ) eq '1' );
+            $result = 1 if ( $self->{db}->add_api_user( $params->{username}, $params->{api_key} ) eq '1' );
         }
     };
     if ($@) {
@@ -642,16 +627,16 @@ sub get_batch_job_result {
     my ( $self, $params ) = @_;
 
     my $result;
-    
+
     eval {
-        my $batch_id = $params->{"batch_id"};
+        my $batch_id = $params->{batch_id};
 
         $result = $self->{db}->get_batch_job_result($batch_id);
     };
     if ($@) {
         handle_exception('get_batch_job_result', $@, '016');
     }
-    
+
     return $result;
 }
 
@@ -662,31 +647,45 @@ sub jsonrpc_validate {
     my ( $self, $jsonrpc_request) = @_;
 
     my @error_rpc = $rpc_request->validate($jsonrpc_request);
-    if (!exists $jsonrpc_request->{"id"} || @error_rpc) {
+    if (!exists $jsonrpc_request->{id} || @error_rpc) {
         return {
             jsonrpc => '2.0',
             id => undef,
             error => {
                 code => '-32600',
-                message=> 'The JSON sent is not a valid request object.',
-                data => "@error_rpc\n"
+                message => 'The JSON sent is not a valid request object.',
+                data => "@error_rpc"
             }
         }
     }
 
-    if (exists $jsonrpc_request->{"params"}) {
-
-        my @error = $json_schemas{$jsonrpc_request->{"method"}}->validate($jsonrpc_request->{"params"});
-        return {
+    my $method_schema = $json_schemas{$jsonrpc_request->{method}};
+    # the JSON schema for the method has a 'required' key
+    if ( exists $method_schema->{required} ) {
+        if ( not exists $jsonrpc_request->{params} ) {
+            return {
                 jsonrpc => '2.0',
-                id => undef,
+                id => $jsonrpc_request->{id},
                 error => {
                     code => '-32602',
-                    message=> 'Invalid method parameter(s).',
-                    data => "@error\n"
+                    message => "Missing 'params' object",
                 }
-            } if @error;
+            };
+        }
+        my @error = $method_schema->validate($jsonrpc_request->{params});
+        if ( @error ) {
+            return {
+                jsonrpc => '2.0',
+                id => $jsonrpc_request->{id},
+                error => {
+                    code => '-32602',
+                    message => 'Invalid method parameter(s).',
+                    data => "@error"
+                }
+            };
+        }
     }
+
     return '';
 }
 1;
