@@ -7,6 +7,7 @@ use 5.14.2;
 use Moose;
 use Encode;
 use POSIX qw[setlocale LC_MESSAGES LC_CTYPE];
+use Zonemaster::Backend::Config;
 
 # Zonemaster Modules
 require Zonemaster::Engine::Translator;
@@ -15,22 +16,9 @@ require Zonemaster::Engine::Logger::Entry;
 extends 'Zonemaster::Engine::Translator';
 
 sub translate_tag {
-    my ( $self, $entry, $browser_lang ) = @_;
-
-    my $previous_locale = $self->locale;
-    if ( $browser_lang eq 'fr' ) {
-        $self->locale( "fr_FR.UTF-8" );
-    }
-    elsif ( $browser_lang eq 'sv' ) {
-        $self->locale( "sv_SE.UTF-8" );
-    }
-    elsif ( $browser_lang eq 'da' ) {
-        $self->locale( "da_DK.UTF-8" );
-    }
-    else {
-        $self->locale( "en_US.UTF-8" );
-    }
+    my ( $self, $hashref, $browser_lang ) = @_;
 
+    # Workaround for broken Zonemaster::Engine::translate_tag in Zonemaster-Engine 3.1.2.
     # Make locale really be set. Fix that makes translation work on FreeBSD 12.1. Solution copied from
     # CLI.pm in the Zonemaster-CLI repository.
     undef $ENV{LANGUAGE};
@@ -44,17 +32,10 @@ sub translate_tag {
         $ENV{LC_ALL} || $ENV{LC_CTYPE};
     }
 
-    my $string = $self->data->{ $entry->{module} }{ $entry->{tag} };
+    my $entry = Zonemaster::Engine::Logger::Entry->new( %{ $hashref } );
+    my $octets = Zonemaster::Engine::Translator::translate_tag( $self, $entry );
 
-    if ( not $string ) {
-        return $entry->{string};
-    }
-
-    my $blessed_entry = bless($entry, 'Zonemaster::Engine::Logger::Entry');
-    my $octets = Zonemaster::Engine::Translator::translate_tag( $self, $blessed_entry );
-    $self->locale( $previous_locale );
-    my $str = decode_utf8( $octets );
-    return $str;
+    return decode_utf8( $octets );
 }
 
 1;
