@@ -7,14 +7,13 @@ use Encode;
 use DBI qw(:utils);
 
 use Zonemaster::Backend::Config;
+use Zonemaster::Backend::DB::MySQL;
 
-die "The configuration file does not contain the MySQL backend" unless (lc(Zonemaster::Backend::Config->load_config()->BackendDBType()) eq 'mysql');
-my $db_user = Zonemaster::Backend::Config->load_config()->DB_user();
-my $db_password = Zonemaster::Backend::Config->load_config()->DB_password();
-my $db_name = Zonemaster::Backend::Config->load_config()->DB_name();
-my $connection_string = Zonemaster::Backend::Config->load_config()->DB_connection_string();
-
-my $dbh = DBI->connect( $connection_string, $db_user, $db_password, { RaiseError => 1, AutoCommit => 1 } );
+my $config = Zonemaster::Backend::Config->load_config();
+if ( $config->DB_engine ne 'MySQL' ) {
+    die "The configuration file does not contain the MySQL backend";
+}
+my $dbh = Zonemaster::Backend::DB::MySQL->new( { config => $config } )->dbh;
 
 sub create_db {
 
