@@ -7,20 +7,20 @@ use Encode;
 use DBI qw(:utils);
 
 use Zonemaster::Backend::Config;
-use Zonemaster::Backend::DB::PostgreSQL;
+use Zonemaster::Backend::DB::MySQL;
 
 my $config = Zonemaster::Backend::Config->load_config();
-if ( $config->DB_engine ne 'PostgreSQL' ) {
-    die "The configuration file does not contain the PostgreSQL backend";
+if ( $config->DB_engine ne 'MySQL' ) {
+    die "The configuration file does not contain the MySQL backend";
 }
-my $dbh = Zonemaster::Backend::DB::PostgreSQL->new( { config => $config } )->dbh;
+my $dbh = Zonemaster::Backend::DB::MySQL->new( { config => $config } )->dbh;
 
 sub patch_db {
 
     ####################################################################
     # TEST RESULTS
     ####################################################################
-    $dbh->do( 'ALTER TABLE test_results ADD COLUMN nb_retries INTEGER NOT NULL DEFAULT 0' );
+    $dbh->do( 'ALTER TABLE test_results ADD COLUMN hash_id VARCHAR(16) DEFAULT substring(md5(random()::text || clock_timestamp()::text) from 1 for 16) NOT NULL' );
 }
 
 patch_db();
